<?php
include '/var/www/sites/basic/db_connect.php';

class Member {
	var $id;
	var $wp_id;
	var $username;
	var $password;
	var $tlf;
	var $session;
	var $lastaccess;
	var $smscode;
	var $smscodetimestamp;
	var $ip;
	var $firstname;
	var $surname;
	var $email;
	var $role;
			
	function Member($username = '', $password = '', $tlf = '', $firstname = '', $surname = '', $email = '', $role = '') {
		$this->username = $username;
		$this->password = $password;
		$this->session = null;
		$this->ip = null;
		$this->tlf = $tlf;
		$this->smscode = null;
		$this->smscodetimestamp = null;
		$this->firstname = $firstname;
		$this->surname = $surname;
		$this->email = $email;
		$this->lastaccess = null;
		$this->role = $role;
	}
    
    /**
    *============THIS FUNCTION ADDS NEW MEMBERS TO THE MOBESITY PROJECT============
    *
    * The user is first added to the mobesity database, which is the database used for authentication of users. 
    * The user is then added to wordpress database and given the correct metadata there. 
    * The user is then added to the forum database so that he/she can access the forum.
    * Lastly the user is added to the webcalender forum so he/she can access the calendar. 
    */
	function insertMember() {
		require_once '/var/www/sites/wordpress/wp-includes/registration.php';
		try {
			$this->insertMobUser();
			$userarray = array(
				'user_login'    => $this->username,
				'user_pass'    => $this->password,
				'user_nicename' => $this->firstname.' '.$this->surname,
				'display_name' => $this->firstname.' '.$this->surname,
				'user_email'    => $this->email,
				'first_name'    => $this->firstname,
				'last_name'    => $this->surname
			);
			wp_insert_user($userarray); //wordpress' method for adding user. Also adds a user to simple forum.
			$this->updateSFUser(); //Needed to set the proper groupdependencies (This is not passed by using the wp_insert_user method
			$this->insertWebcalUser(); //Adds the webcal user
			
			return true;
		} catch (Exception $e) {
			printf("Error: insertMember(): %s\n",$e->__toString());
			return false;
		}
	}
	/**
	*	This method inserts the user into the Mobesity-db
	*/
	function insertMobUser() { 
		//ADD USER TO MOBESITY DATABASE
		$mdb2 = db_connect('mobesity');
		$table_name = 'member';
		$fields_values = array(
			'username'    => $this->username,
			'password'    => $this->password,
			'session'    => $this->session,
			'role'    => $this->role,
			'email'    => $this->email,
			'lastaccess'    => $this->session,
			'ip'    => $this->ip,
			'tlf'    => $this->tlf,
			'smscode'    => $this->smscode,
			'smscodetimestamp'    => $this->smscodetimestamp,
			'firstname'    => $this->firstname,
			'surname'    => $this->surname
		);
		$types = array('text', 'text', 'text', 'tinyint', 'text', 'text', 'text', 'text', 'text', 'text', 'text', 'text');
		
		$mdb2->loadModule('Extended');
		$affectedRows = $mdb2->extended->autoExecute($table_name, $fields_values,
					MDB2_AUTOQUERY_INSERT, $types);
		
		if (PEAR::isError($affectedRows)) {
			die($affectedRows->getMessage());
		}
	}
	function insertWpUser() { //Deprecated
		 trigger_error("Deprecated function called.", E_USER_NOTICE);
		//$this->toPrint("insertWpUser()");
		
		//ADD USER TO WORDPRESS DATABASE
		$mdb2 = db_connect('wordpress');
		
		$wpUserTable = 'wp_users';
		$wp_fields_values = array(
			'user_login'    => $this->username,
			'user_pass'    => $this->password,
			'user_email'    => $this->email, 
			'display_name'  => $this->firstname.' '.$this->surname 
		);
		$wpTypes = array('text', 'text', 'text', 'text');
		$mdb2->loadModule('Extended');
		$affectedRows = $mdb2->extended->autoExecute($wpUserTable, $wp_fields_values,
					MDB2_AUTOQUERY_INSERT, $wpTypes);
		
		if (PEAR::isError($affectedRows)) {
			die($affectedRows->getMessage());
		}
		
		//ADD THE USER METADATA IN WORDPRESS
		$sql = 'SELECT * FROM wp_users WHERE user_login=? AND user_email = ?';
		$types = array('text', 'text');
		$sth = $mdb2->prepare($sql, $types);
		$data = array($this->username, $this->email);
		$result = $sth->execute($data); 
		
		if ($result->numRows()==1) {
			$row = $result->fetchRow();
			$this->wp_id = $row['id'];
		}
			else {                   
				die('Could not get userID of added user. Metadata not added.');
		}
		$wpUserMetaTable = 'wp_usermeta';
		$mdb2->loadModule('Extended');
		$meta = array(
			'first_name'        =>$this->firstname,
			'last_name'         =>$this->surname,
			'wp_capabilities'   =>'a:1:{s:10:"subscriber";b:1;}',
			'nickname'          =>$this->username
		);
		
		$wp_metaTypes = array('int', 'text', 'text'); 
		while(key($meta) != null)    {
			$wp_meta_fields_values = array(
				'user_id'   =>$this->wp_id,
				'meta_key'  =>key($meta),
				'meta_value'=>$meta[key($meta)]
			);
			next($meta);
			$affectedRows = $mdb2->extended->autoExecute($wpUserMetaTable, $wp_meta_fields_values, MDB2_AUTOQUERY_INSERT, $wp_metaTypes);            
			if (PEAR::isError($affectedRows))  {            
				die($affectedRows->getMessage());
			}
		}
	}
	function insertSFMember() { //Deprecated
		trigger_error("Deprecated function called.", E_USER_NOTICE);
		
		$mdb2 = db_connect('wordpress');
		
		// Look up wp id
		$sql = 'SELECT * FROM wp_users WHERE user_login=? AND user_email = ?';
		$types = array('text', 'text');
		$sth = $mdb2->prepare($sql, $types);
		$data = array($this->username, $this->email);
		$result = $sth->execute($data); 
		
		if ($result->numRows()==1) {
			$row = $result->fetchRow();
			$this->wp_id = $row['id'];
		}
			else {                   
				die('Could not get userID of added user. Metadata not added.');
		}
		$this->toPrint("insertSFUser()");
		
		//ADD USER TO THE FORUM
		$wpSFUserTable = 'wp_sfmembers';
		$wp_SFfields_values = array(
			'user_id'    => $this->wp_id,
			'display_name'    => $this->firstname.' '.$this->surname,
			'pm'        => '1', 
			'moderator'  => '0',
			'admin' => '0'
		);
		$wpSFTypes = array('int', 'text', 'int', 'int', 'int');
		$mdb2->loadModule('Extended');
		$affectedRows = $mdb2->extended->autoExecute($wpSFUserTable, $wp_SFfields_values,
					MDB2_AUTOQUERY_INSERT, $wpSFTypes);
		
		if (PEAR::isError($affectedRows)) {
			die($affectedRows->getMessage());
		}
		$this->toPrint("insertSFUser()");
		
		//ADD THE USER TO A CERTAIN GROUP BASED ON THE ROLE INPUT
		$wpSFUserTable = 'wp_sfmemberships';
		$wp_SFfields_values = array(
			'user_id'   => $this->wp_id,
			'usergroup_id'  => $this->role
		);
		$wpSFTypes = array('int', 'int');
		$mdb2->loadModule('Extended');
		$affectedRows = $mdb2->extended->autoExecute($wpSFUserTable, $wp_SFfields_values,
					MDB2_AUTOQUERY_INSERT, $wpSFTypes);
		
		if (PEAR::isError($affectedRows)) {
			die($affectedRows->getMessage());
		}
	}
	function updateSFUser() {
		$mdb2 = db_connect('wordpress');
		
		// Look up wp id
		$sql = 'SELECT * FROM wp_users WHERE user_login=? AND user_email = ?';
		$types = array('text', 'text');
		$sth = $mdb2->prepare($sql, $types);
		$data = array($this->username, $this->email);
		$result = $sth->execute($data); 
		
		if ($result->numRows()==1) {
			$row = $result->fetchRow();
			$this->wp_id = $row['id'];
		}
			else {                   
				die('Could not get wordpress-id of added user.');
		}
		
		//Assign the correct role/group
		$wpSFUserTable = 'wp_sfmemberships';
		$wp_SFfields_values = array(
			'usergroup_id'  => $this->role
		);
		
		$mdb2->loadModule('Extended');
		$affectedRows = $mdb2->extended->autoExecute($wpSFUserTable, $wp_SFfields_values,
					MDB2_AUTOQUERY_UPDATE, 'user_id = '.$this->wp_id);
		
		if (PEAR::isError($affectedRows)) {
			die($affectedRows->getMessage());
		}
	}
	function insertWebcalUser() {
		//ADD USER TO WEBCALENDAR DATABASE
		$mdb2 = db_connect('webcal');
		$mdb2->loadModule('Extended');
		
		$wcUserTable = 'webcal_user';
		$wc_fields_values = array(
			'cal_login'     =>$this->username,
			'cal_passwd'    =>$this->password,
			'cal_lastname'  =>$this->surname,
			'cal_firstname' =>$this->firstname,
			'cal_email'     =>$this->email,
			'cal_telephone' =>$this->tlf
		);
		$wcTypes = array('text','text','text','text','text','text');
		
		$affectedRows = $mdb2->extended->autoExecute($wcUserTable, $wc_fields_values,
					MDB2_AUTOQUERY_INSERT, $wcTypes);
		if (PEAR::isError($affectedRows)) {
			die($affectedRows->getMessage());
		}
		$wcUserTable = 'webcal_user_pref';
		$settings = array(
			'LANGUAGE'  => 'Norwegian',
			'TIMEZONE'  => 'Europe/Oslo'
		);
		$wcTypes = array('text','text','text');
		
		while(key($settings) != null)
		{
			$wc_fields_values = array(
				'cal_login' => $this->username,
				'cal_setting' => key($settings),            
				'cal_value' => $settings[key($settings)]
			);
			next($settings);
			
			$affectedRows = $mdb2->extended->autoExecute($wcUserTable, $wc_fields_values,
					MDB2_AUTOQUERY_INSERT, $wcTypes);
		}
		if (PEAR::isError($affectedRows)) {
				die($affectedRows->getMessage());
			}
	}
	function getMember($username) {
		try {
			$mdb2 = db_connect('mobesity');
			
			$sql = 'SELECT * FROM member WHERE username=?';
			$types = array('text');
			$sth = $mdb2->prepare($sql, $types);
			$data = array($username);
			$result = $sth->execute($data);
			
			if ($result->numRows()==1) {
				$row = $result->fetchRow();
				$this->id = $row['id'];
				$this->ip = $row['ip'];
                $this->tlf = $row['tlf'];
				$this->lastaccess = $row['lastaccess'];
				$this->username = $row['username'];
				$this->password = $row['password'];
				$this->session = $row['session'];
				$this->smscode = $row['smscode'];
				$this->smscodetimestamp = $row['smscodetimestamp'];
				$this->firstname = $row['firstname'];
				$this->surname = $row['surname'];
				$this->email = $row['email'];
				$this->role = $row['role'];
			}
			else {
				$this->id = null;
			}
			if (PEAR::isError($mdb2)) {
				echo die($mdb2->getMessage());
			}
			
			return $this;
			
		} catch (Exception $e) {
			printf("Error:getmember: %s\n",$e->__toString());
			return false;
		}
	}
	function getMemberBySession($session) {
		try {
			$mdb2 = db_connect('mobesity');
			
			$sql = 'SELECT * FROM member WHERE session=?';
			$types = array('text');
			$sth = $mdb2->prepare($sql, $types);
			$data = array($session);
			$result = $sth->execute($data);
			
			if ($result->numRows()==1) {
				$row = $result->fetchRow();
				$this->id = $row['id'];
				$this->ip = $row['ip'];
                $this->tlf = $row['tlf'];
				$this->lastaccess = $row['lastaccess'];
				$this->username = $row['username'];
				$this->password = $row['password'];
				$this->session = $row['session'];
				$this->smscode = $row['smscode'];
				$this->smscodetimestamp = $row['smscodetimestamp'];
				$this->firstname = $row['firstname'];
				$this->surname = $row['surname'];
				$this->email = $row['email'];
				$this->role = $row['role'];
			}
			if (PEAR::isError($mdb2)) {
				echo die($mdb2->getMessage());
			}
				
			return $this;
			
		} catch (Exception $e) {
			printf("Error:getmember: %s\n",$e->__toString());
			return false;
		}
	}
	/**
	* This method retrieves all the members for the Mobesity-db.
	* Exception: Does not return administrators
	*/
	static function getAllDBMembers() {
	try {
		$mdb2 = db_connect('mobesity');
		
		$sql = 'SELECT username, firstname, surname FROM member WHERE role != \'6\'ORDER BY surname';
		$result = $mdb2->query($sql);
		
		$memberList = array();
		while ($row = $result->fetchRow()) {
			$member = new Member();
			$member->username = $row['username'];
			$member->firstname = $row['firstname'];
			$member->surname = $row['surname'];
			$memberList[] = $member;
		}
		if (PEAR::isError($mdb2)) {
			echo die($mdb2->getMessage());
		}
			
		return $memberList;
			
	} catch (Exception $e) {
		printf("Error:getAllMembers: %s\n",$e->__toString());
		return false;
	}
	}
	function updateMember() {
		try {
			$mdb2 = db_connect('mobesity');
			
			$table_name = 'member';
			$fields_values = array(
				'wordpress_id' => $this->wp_id,
				'session'    => $this->session,
				'ip'    => $this->ip,
				'tlf'    => $this->tlf,
				'smscode'    => $this->smscode,
				'smscodetimestamp'    => $this->smscodetimestamp,
				'firstname'    => $this->firstname,
				'surname'    => $this->surname,
				'password' => $this->password,
				'email' => $this->email,
				'lastaccess' => $this->lastaccess,
				'role' => $this->role
			);
			$types = array('int', 'text', 'text', 'text', 'text', 'text', 'text', 'text', 'text', 'text', 'text', 'int');
			
			$mdb2->loadModule('Extended');
			$affectedRows = $mdb2->extended->autoExecute($table_name, $fields_values,
						MDB2_AUTOQUERY_UPDATE, 'id = '.$this->id, $types);

			if (PEAR::isError($affectedRows)) {
				die($affectedRows->getMessage());
			}
			
		} catch (Exception $e) {
			printf("Error:updateMember: %s\n",$e->__toString());
		}
	}
	function updateMemberPw($newPassword) {
		try {
			$mdb2 = db_connect('mobesity');
			
			$table_name = 'member';
			$fields_values = array(
				'password' => $newPassword
			);
			$types = array('text');
			
			$mdb2->loadModule('Extended');
			$affectedRows = $mdb2->extended->autoExecute($table_name, $fields_values,
						MDB2_AUTOQUERY_UPDATE, 'id = '.$this->id, $types);

			if (PEAR::isError($affectedRows)) {
				die($affectedRows->getMessage());
			}
			return true;
		} catch (Exception $e) {
			printf("Error:updateMemberPw: %s\n",$e->__toString());
		}
	}
	function updateSms($smscode, $smscodetimestamp) {
		try {
			$mdb2 = db_connect('mobesity');
			
			$table_name = 'member';
			$fields_values = array(
				'session'    => session_id(),
				'lastaccess'    => time(),
				'ip'    => $_SERVER['REMOTE_ADDR'],
				'smscode'    => $smscode,
				'smscodetimestamp'    => $smscodetimestamp
			);
			$types = array('text', 'text', 'text', 'text', 'text');
			
			$mdb2->loadModule('Extended');
			$affectedRows = $mdb2->extended->autoExecute($table_name, $fields_values,
						MDB2_AUTOQUERY_UPDATE, 'id = '.$this->id, $types);

			if (PEAR::isError($affectedRows)) {
				die($affectedRows->getMessage());
			}
			
		} catch (Exception $e) {
			printf("Error:updateSms: %s\n",$e->__toString());
		}
	}
	function updateAccess() {
		try {
			$mdb2 = db_connect('mobesity');
			
			$table_name = 'member';
			$fields_values = array(
				'session'    => session_id(),
				'lastaccess'    => time(),
				'ip'    => $_SERVER['REMOTE_ADDR']
			);
			$types = array('text', 'text', 'text');
			
			$mdb2->loadModule('Extended');
			$affectedRows = $mdb2->extended->autoExecute($table_name, $fields_values,
						MDB2_AUTOQUERY_UPDATE, 'id = '.$this->id, $types);

			if (PEAR::isError($affectedRows)) {
				die($affectedRows->getMessage());
			}
			
		} catch (Exception $e) {
			printf("Error:updateAccess: %s\n",$e->__toString());
		}
	}
	function deleteDBUser() {
		require_once '/var/www/sites/wordpress/wp-admin/includes/user.php';
        require_once 'webcal_methods.php';
		try {
            //DELETE FROM MOBESITY DATABASE
            $mdb2 = db_connect('mobesity');
            $table_name = 'member';
            			
            $mdb2->loadModule('Extended');     
            $affectedRows = $mdb2->extended->autoExecute($table_name, null,
						MDB2_AUTOQUERY_DELETE, 'id ='.$this->id);
            if (PEAR::isError($affectedRows)) {
				die($affectedRows->getMessage());
			}
            //Get the users wordpress_ID
            $mdb2 = db_connect('wordpress');
            $table_name = 'wp_users';
            
            $sql = 'SELECT * FROM wp_users WHERE user_login=?';
            $types = array('text');
            $sth = $mdb2->prepare($sql, $types);
            $data = array($this->username);
            $result = $sth->execute($data); 
            
            if ($result->numRows()==1) {
                $row = $result->fetchRow();
                $this->wp_id = $row['id'];
            }
                else {                   
                    die('Could not get userID of added user. Found more than one user with that username');
            }
            
            //Delete from wordpress
            wp_delete_user($this->wp_id);
        
            //Delete from webcalendar
            delete_webcal_user($this->username);
			
			return true;
        } catch (Exception $e)  {
            printf("ERROR:deleteDBUserById: %s\n",$e->__toString());
			return false;
        }
	}
	function toString() {
		$tostring = "\t Username: ".$this->username."\r \n".
					"\t ID: ".$this->id."\r \n".
					"\t WP_ID: ".$this->wp_id."\r \n".
					"\t Firstname: ".$this->firstname."\r \n".
					"\t Surname: ".$this->surname."\r \n".
					"\t Tlf: ".$this->tlf."\r \n".
					"\t Email: ". $this->email."\r \n".
					"\t Role: ".$this->role."\r \n".
					"\t Session: ".$this->session."\r \n".
					"\t Smscode: ".$this->smscode."\r \n".
					"\t Smscodetimestamp: ".$this->smscodetimestamp."\r \n".
					"\t lastaccess: ". $this->lastaccess."\r \n".
					"\t IP: ". $this->ip."\r \n";
		return $tostring;
	}
	function toPrint($calledMethod) {
		$myFile = "/home/tarjei/test.txt";
		$fh = fopen($myFile, 'a') or die("can't open file");
		fwrite($fh, "\t". $calledMethod . ": \r \n");
		fwrite($fh, $this->toString(). "\r \n");
		fclose($fh);
	}
}
?>